`databricks-dolly-15k` is an open source dataset of instruction-following
records used in training
[databricks/dolly-v2-12b](https://huggingface.co/databricks/dolly-v2-12b) that
was generated by thousands of Databricks employees in several of the behavioral
categories outlined in the [InstructGPT](https://arxiv.org/abs/2203.02155)
paper, including brainstorming, classification, closed QA, generation,
information extraction, open QA, and summarization.

This dataset can be used for any purpose, whether academic or commercial, under
the terms of the
[Creative Commons Attribution-ShareAlike 3.0 Unported License](https://creativecommons.org/licenses/by-sa/3.0/legalcode).
